@@ -1,6 +1,7 @@
-from typing import Any, Dict, List, Optional, Union
+from typing import Any, Optional, Union
 
 from ytmusicapi.continuations import get_continuations
+from ytmusicapi.exceptions import YTMusicUserError
 from ytmusicapi.mixins._protocol import MixinProtocol
 from ytmusicapi.parsers.search import *
 
@@ -13,7 +14,7 @@ class SearchMixin(MixinProtocol):
         scope: Optional[str] = None,
         limit: int = 20,
         ignore_spelling: bool = False,
-    ) -> List[Dict]:
+    ) -> list[dict]:
         """
         Search YouTube music
         Returns results within the provided category.
@@ -136,7 +137,7 @@ class SearchMixin(MixinProtocol):
         """
         body = {"query": query}
         endpoint = "search"
-        search_results: List[Dict[str, Any]] = []
+        search_results: list[dict[str, Any]] = []
         filters = [
             "albums",
             "artists",
@@ -150,26 +151,26 @@ class SearchMixin(MixinProtocol):
             "episodes",
         ]
         if filter and filter not in filters:
-            raise Exception(
+            raise YTMusicUserError(
                 "Invalid filter provided. Please use one of the following filters or leave out the parameter: "
                 + ", ".join(filters)
             )
 
         scopes = ["library", "uploads"]
         if scope and scope not in scopes:
-            raise Exception(
+            raise YTMusicUserError(
                 "Invalid scope provided. Please use one of the following scopes or leave out the parameter: "
                 + ", ".join(scopes)
             )
 
         if scope == scopes[1] and filter:
-            raise Exception(
+            raise YTMusicUserError(
                 "No filter can be set when searching uploads. Please unset the filter parameter when scope is set to "
                 "uploads. "
             )
 
         if scope == scopes[0] and filter in filters[3:5]:
-            raise Exception(
+            raise YTMusicUserError(
                 f"{filter} cannot be set when searching library. "
                 f"Please use one of the following filters or leave out the parameter: "
                 + ", ".join(filters[0:3] + filters[5:])
@@ -257,7 +258,7 @@ class SearchMixin(MixinProtocol):
 
         return search_results
 
-    def get_search_suggestions(self, query: str, detailed_runs=False) -> Union[List[str], List[Dict]]:
+    def get_search_suggestions(self, query: str, detailed_runs=False) -> Union[list[str], list[dict]]:
         """
         Get Search Suggestions
 
