@@ -1,10 +1,10 @@
 import gettext
 import json
 import locale
-import os
 import time
 from contextlib import suppress
 from functools import partial
+from pathlib import Path
 from typing import Optional, Union
 
 import requests
@@ -121,12 +121,11 @@ class YTMusicBase:
             self.oauth_credentials = (
                 oauth_credentials if oauth_credentials is not None else OAuthCredentials()
             )
-            auth_filepath: Optional[str] = None
+            auth_path: Optional[Path] = None
             if isinstance(self.auth, str):
                 auth_str: str = self.auth
-                if os.path.isfile(auth_str):
-                    with open(auth_str) as json_file:
-                        auth_filepath = auth_str
+                if (auth_path := Path(auth_str)).is_file():
+                    with open(auth_path) as json_file:
                         input_json = json.load(json_file)
                 else:
                     input_json = json.loads(auth_str)
@@ -137,7 +136,7 @@ class YTMusicBase:
 
             if OAuthToken.is_oauth(self._input_dict):
                 self._token = RefreshingToken(
-                    credentials=self.oauth_credentials, _local_cache=auth_filepath, **self._input_dict
+                    credentials=self.oauth_credentials, _local_cache=auth_path, **self._input_dict
                 )
                 self.auth_type = AuthType.OAUTH_CUSTOM_CLIENT if oauth_credentials else AuthType.OAUTH_DEFAULT
 
@@ -161,7 +160,7 @@ class YTMusicBase:
             with suppress(locale.Error):
                 locale.setlocale(locale.LC_ALL, "en_US.UTF-8")
 
-        locale_dir = os.path.abspath(os.path.dirname(__file__)) + os.sep + "locales"
+        locale_dir = Path(__file__).parent.resolve() / "locales"
         self.lang = gettext.translation("base", localedir=locale_dir, languages=[language])
         self.parser = Parser(self.lang)
 
